Subject: [bug#75051] [PATCH v2 14/15] gnu: pcre2: disable jit on loongarch64.

From: Zheng Junjie <[email-masked]>
Date: Sat, 25 Jan 2025 00:39:12 +0800

From: Zheng Junjie <[email-masked]>

* gnu/packages/pcre.scm (pcre2)[arguments]<#:configure-flags>: when
target loongarch64, don't pass --enable-jit.

Change-Id: I5c57da334da0d9fe33e3ec7963a4967e5463d125
---
 gnu/packages/pcre.scm | 6 ++++--
 1 file changed, 4 insertions(+), 2 deletions(-)

diff --git a/gnu/packages/pcre.scm b/gnu/packages/pcre.scm
index 6f31d3c1d7e..1dbd2180a84 100644
--- a/gnu/packages/pcre.scm
+++ b/gnu/packages/pcre.scm
@@ -112,8 +112,10 @@ (define-public pcre2
                "--enable-pcre2test-libreadline"
                "--enable-pcre2-16"
                "--enable-pcre2-32"
-               ;; riscv64-linux is an unsupported architecture.
-               #$@(if (target-riscv64?)
+               ;; riscv64-linux and loongarch64-linux is an unsupported
+               ;; architecture.
+               #$@(if (or (target-riscv64?)
+                          (target-loongarch64?))
                       #~()
                       #~("--enable-jit")))
            #:phases
-- 
2.47.1